# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

"""
IDs of the items that can be displayed in Eric's inventory. The image
specifications for each item are defined in the `Inventory` section of the ini
file.
"""

#: Captured frog.
FROG = 'FROG'
#: Captured mouse.
MOUSE = 'MOUSE'
#: Safe key.
SAFE_KEY = 'SAFE_KEY'
#: Water pistol containing sherry.
SHERRY_PISTOL = 'SHERRY_PISTOL'
#: Three stinkbombs.
STINKBOMBS3 = 'STINKBOMBS3'
#: Two stinkbombs.
STINKBOMBS2 = 'STINKBOMBS2'
#: One stinkbomb.
STINKBOMBS1 = 'STINKBOMBS1'
#: Science Lab storeroom key.
STOREROOM_KEY = 'STOREROOM_KEY'
#: Water pistol containing water.
WATER_PISTOL = 'WATER_PISTOL'
